==> nan_common_utils-0.0.23.tar.gz: lib/nan_map_page.dart <==

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:nan_common_utils/nan_widget_util.dart';

const VIEW_TYPE = 'com.amap.flutter.map';
const BasicMessageChannel<dynamic> messageChannel = const BasicMessageChannel("testDidiView2", StandardMessageCodec());



class NanMapPage extends StatefulWidget{

  final String apiKey;
  NanMapPage({
    Key key,
    this.apiKey
  }):super(key: key);

  @override
  _NanMapPageState createState() => _NanMapPageState();


}
class _NanMapPageState extends State<NanMapPage>{

  @override
  void initState() {
    super.initState();
    messageChannel.setMessageHandler((message)async{
      // setState(() {
      //   address = message.address;
      // });
      // NanUtil.showUploadDialog(context,tipMsg: "正在加载中...");
      // setState(() {
      //   address = message["address"];
      // });
    });
  }

  @override
  void dispose() {
    super.dispose();

  }


  @override
  Widget build(BuildContext context) {

    return Scaffold(
      appBar: NanWidgetUtil.commonAppBar(title: "地图选择"),
      body: Platform.isIOS?UiKitView(
        viewType: VIEW_TYPE,
        // onPlatformViewCreated: onPlatformViewCreated,
        // gestureRecognizers: gestureRecognizers,
        creationParams: creationParams,
        creationParamsCodec: const StandardMessageCodec(),
      ):AndroidView(
        viewType: VIEW_TYPE,
        creationParams: creationParams,
        creationParamsCodec: const StandardMessageCodec(),
      ),
    );
  }

  final Map<String, dynamic> creationParams = <String, dynamic>{
      'apiKey': "36501b8488ba6322b5ec5b7ef40c773f",
    };
}

==> nan_common_utils-0.0.27.tar.gz: lib/nan_map_page.dart <==

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:nan_common_utils/nan_widget_util.dart';

const VIEW_TYPE = 'com.amap.flutter.map';
const BasicMessageChannel<dynamic> messageChannel = const BasicMessageChannel("testDidiView2", StandardMessageCodec());



class NanMapPage extends StatefulWidget{

  final String apiKey;
  final Function finishFun;
  NanMapPage({
    Key key,
    this.apiKey,
    this.finishFun
  }):super(key: key);

  @override
  _NanMapPageState createState() => _NanMapPageState();


}
class _NanMapPageState extends State<NanMapPage>{

  @override
  void initState() {
    super.initState();
    messageChannel.setMessageHandler((message)async{
      // setState(() {
      //   address = message.address;
      // });
      // NanUtil.showUploadDialog(context,tipMsg: "正在加载中...");
      // setState(() {
      //   address = message["address"];
      // });
      if (widget.finishFun != null) {
        widget.finishFun(message);
        Navigator.pop(context);
      }
    });
  }

  @override
  void dispose() {
    super.dispose();

  }


  @override
  Widget build(BuildContext context) {

    return Scaffold(
      appBar: NanWidgetUtil.commonAppBar(title: "地图选择",actions: <Widget>[
          NanWidgetUtil.builderItem(title: '确定',onTap: () {
            messageChannel.send({"method":'haha'});
          },),
        ]),
      body: Platform.isIOS?UiKitView(
        viewType: VIEW_TYPE,
        // onPlatformViewCreated: onPlatformViewCreated,
        // gestureRecognizers: gestureRecognizers,
        creationParams: creationParams,
        creationParamsCodec: const StandardMessageCodec(),
      ):AndroidView(
        viewType: VIEW_TYPE,
        creationParams: creationParams,
        creationParamsCodec: const StandardMessageCodec(),
      ),
    );
  }

  final Map<String, dynamic> creationParams = <String, dynamic>{
      'apiKey': "36501b8488ba6322b5ec5b7ef40c773f",
    };
}
